# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import arlas_api_python
from arlas_api_python.api.explore_api import ExploreApi  # noqa: E501
from arlas_api_python.rest import ApiException


class TestExploreApi(unittest.TestCase):
    """ExploreApi unit test stubs"""

    def setUp(self):
        self.api = arlas_api_python.api.explore_api.ExploreApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_aggregate(self):
        """Test case for aggregate

        Aggregate  # noqa: E501
        """
        pass

    def test_aggregate_post(self):
        """Test case for aggregate_post

        Aggregate  # noqa: E501
        """
        pass

    def test_compute(self):
        """Test case for compute

        Compute  # noqa: E501
        """
        pass

    def test_compute_post(self):
        """Test case for compute_post

        Compute  # noqa: E501
        """
        pass

    def test_count(self):
        """Test case for count

        Count  # noqa: E501
        """
        pass

    def test_count_post(self):
        """Test case for count_post

        Count  # noqa: E501
        """
        pass

    def test_describe(self):
        """Test case for describe

        Describe  # noqa: E501
        """
        pass

    def test_geoaggregate(self):
        """Test case for geoaggregate

        GeoAggregate  # noqa: E501
        """
        pass

    def test_geoaggregate_post(self):
        """Test case for geoaggregate_post

        GeoAggregate  # noqa: E501
        """
        pass

    def test_geohashgeoaggregate(self):
        """Test case for geohashgeoaggregate

        GeoAggregate on a geohash  # noqa: E501
        """
        pass

    def test_geosearch(self):
        """Test case for geosearch

        GeoSearch  # noqa: E501
        """
        pass

    def test_geosearch_post(self):
        """Test case for geosearch_post

        GeoSearch  # noqa: E501
        """
        pass

    def test_geotilegeoaggregate(self):
        """Test case for geotilegeoaggregate

        GeoAggregate on a geotile  # noqa: E501
        """
        pass

    def test_get_arlas_hit(self):
        """Test case for get_arlas_hit

        Get an Arlas document  # noqa: E501
        """
        pass

    def test_list(self):
        """Test case for list

        List  # noqa: E501
        """
        pass

    def test_search(self):
        """Test case for search

        Search  # noqa: E501
        """
        pass

    def test_search_post(self):
        """Test case for search_post

        Search  # noqa: E501
        """
        pass

    def test_shapeaggregate(self):
        """Test case for shapeaggregate

        ShapeAggregate  # noqa: E501
        """
        pass

    def test_shapeaggregate_post(self):
        """Test case for shapeaggregate_post

        ShapeAggregate  # noqa: E501
        """
        pass

    def test_shapesearch(self):
        """Test case for shapesearch

        ShapeSearch  # noqa: E501
        """
        pass

    def test_shapesearch_post(self):
        """Test case for shapesearch_post

        ShapeSearch  # noqa: E501
        """
        pass

    def test_suggest(self):
        """Test case for suggest

        Suggest  # noqa: E501
        """
        pass

    def test_tiledgeosearch(self):
        """Test case for tiledgeosearch

        Tiled GeoSearch  # noqa: E501
        """
        pass

    def test_tiledgeosearch1(self):
        """Test case for tiledgeosearch1

        Tiled GeoSearch  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
