# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import arlas_api_python
from arlas_api_python.models.multi_point import MultiPoint  # noqa: E501
from arlas_api_python.rest import ApiException


class TestMultiPoint(unittest.TestCase):
    """MultiPoint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMultiPoint(self):
        """Test MultiPoint"""
        # FIXME: construct object with mandatory attributes with example values
        # model = arlas_api_python.models.multi_point.MultiPoint()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
