# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 22.0.0-beta.3
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FeatureCollection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'crs': 'Crs',
        'bbox': 'list[float]',
        'features': 'list[Feature]'
    }

    attribute_map = {
        'crs': 'crs',
        'bbox': 'bbox',
        'features': 'features'
    }

    def __init__(self, crs=None, bbox=None, features=None):  # noqa: E501
        """FeatureCollection - a model defined in Swagger"""  # noqa: E501

        self._crs = None
        self._bbox = None
        self._features = None
        self.discriminator = None

        if crs is not None:
            self.crs = crs
        if bbox is not None:
            self.bbox = bbox
        if features is not None:
            self.features = features

    @property
    def crs(self):
        """Gets the crs of this FeatureCollection.  # noqa: E501


        :return: The crs of this FeatureCollection.  # noqa: E501
        :rtype: Crs
        """
        return self._crs

    @crs.setter
    def crs(self, crs):
        """Sets the crs of this FeatureCollection.


        :param crs: The crs of this FeatureCollection.  # noqa: E501
        :type: Crs
        """

        self._crs = crs

    @property
    def bbox(self):
        """Gets the bbox of this FeatureCollection.  # noqa: E501


        :return: The bbox of this FeatureCollection.  # noqa: E501
        :rtype: list[float]
        """
        return self._bbox

    @bbox.setter
    def bbox(self, bbox):
        """Sets the bbox of this FeatureCollection.


        :param bbox: The bbox of this FeatureCollection.  # noqa: E501
        :type: list[float]
        """

        self._bbox = bbox

    @property
    def features(self):
        """Gets the features of this FeatureCollection.  # noqa: E501


        :return: The features of this FeatureCollection.  # noqa: E501
        :rtype: list[Feature]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this FeatureCollection.


        :param features: The features of this FeatureCollection.  # noqa: E501
        :type: list[Feature]
        """

        self._features = features

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeatureCollection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeatureCollection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
